==> openshift-model-operatorhub-6.9.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/FeaturesFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FeaturesFluent<A extends FeaturesFluent<A>> extends BaseFluent<A>{
  public FeaturesFluent() {
  }
  
  public FeaturesFluent(Features instance) {
    this.copyInstance(instance);
  }
  private Boolean disableCopiedCSVs;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Features instance) {
    instance = (instance != null ? instance : new Features());
    if (instance != null) {
          this.withDisableCopiedCSVs(instance.getDisableCopiedCSVs());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Boolean getDisableCopiedCSVs() {
    return this.disableCopiedCSVs;
  }
  
  public A withDisableCopiedCSVs(Boolean disableCopiedCSVs) {
    this.disableCopiedCSVs = disableCopiedCSVs;
    return (A) this;
  }
  
  public boolean hasDisableCopiedCSVs() {
    return this.disableCopiedCSVs != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeaturesFluent that = (FeaturesFluent) o;
    if (!java.util.Objects.equals(disableCopiedCSVs, that.disableCopiedCSVs)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(disableCopiedCSVs,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (disableCopiedCSVs != null) { sb.append("disableCopiedCSVs:"); sb.append(disableCopiedCSVs + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withDisableCopiedCSVs() {
    return withDisableCopiedCSVs(true);
  }
  

}

==> openshift-model-operatorhub-7.3.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/FeaturesFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FeaturesFluent<A extends FeaturesFluent<A>> extends BaseFluent<A>{
  public FeaturesFluent() {
  }
  
  public FeaturesFluent(Features instance) {
    this.copyInstance(instance);
  }
  private Boolean disableCopiedCSVs;
  private String packageServerSyncInterval;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Features instance) {
    instance = (instance != null ? instance : new Features());
    if (instance != null) {
          this.withDisableCopiedCSVs(instance.getDisableCopiedCSVs());
          this.withPackageServerSyncInterval(instance.getPackageServerSyncInterval());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Boolean getDisableCopiedCSVs() {
    return this.disableCopiedCSVs;
  }
  
  public A withDisableCopiedCSVs(Boolean disableCopiedCSVs) {
    this.disableCopiedCSVs = disableCopiedCSVs;
    return (A) this;
  }
  
  public boolean hasDisableCopiedCSVs() {
    return this.disableCopiedCSVs != null;
  }
  
  public String getPackageServerSyncInterval() {
    return this.packageServerSyncInterval;
  }
  
  public A withPackageServerSyncInterval(String packageServerSyncInterval) {
    this.packageServerSyncInterval = packageServerSyncInterval;
    return (A) this;
  }
  
  public boolean hasPackageServerSyncInterval() {
    return this.packageServerSyncInterval != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeaturesFluent that = (FeaturesFluent) o;
    if (!java.util.Objects.equals(disableCopiedCSVs, that.disableCopiedCSVs)) return false;
    if (!java.util.Objects.equals(packageServerSyncInterval, that.packageServerSyncInterval)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(disableCopiedCSVs,  packageServerSyncInterval,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (disableCopiedCSVs != null) { sb.append("disableCopiedCSVs:"); sb.append(disableCopiedCSVs + ","); }
    if (packageServerSyncInterval != null) { sb.append("packageServerSyncInterval:"); sb.append(packageServerSyncInterval + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withDisableCopiedCSVs() {
    return withDisableCopiedCSVs(true);
  }
  

}
